@@ -22,17 +22,20 @@ from zope.schema import Bool
 from zope.exceptions.interfaces import UserError
 from zope.formlib._compat import basestring
 
+
 class IInvalidFormError(Interface):
 
     def doc():
         """The form submit could not be validated.
         """
 
+
 @implementer(IInvalidFormError)
 class InvalidFormError(Exception):
     """The form submit could not be validated.
     """
 
+
 class IInvalidCSRFTokenError(Interface):
 
     def doc():
@@ -40,18 +43,21 @@ class IInvalidCSRFTokenError(Interface):
         or incorrect.
         """
 
+
 @implementer(IInvalidCSRFTokenError)
 class InvalidCSRFTokenError(InvalidFormError):
     """The form submit could not be handled as the CSRF token is missing
     or incorrect.
     """
 
+
 class IWidgetInputError(Interface):
     """Placeholder for a snippet View"""
 
     def doc():
         """Returns a string that represents the error message."""
 
+
 @implementer(IWidgetInputError)
 class WidgetInputError(UserError):
     """One or more user input errors occurred."""
@@ -92,6 +98,7 @@ class ConversionError(Exception):
     def doc(self):
         return self.error_name
 
+
 InputErrors = WidgetInputError, ValidationError, ConversionError
 
 
@@ -114,10 +121,11 @@ class ErrorContainer(Exception):
         return "\n".join(
             ["%s: %s" % (error.__class__.__name__, error)
              for error in self.args]
-            )
+        )
 
     __repr__ = __str__
 
+
 class WidgetsError(ErrorContainer):
     """A collection of errors from widget processing.
 
@@ -129,6 +137,7 @@ class WidgetsError(ErrorContainer):
         ErrorContainer.__init__(self, *errors)
         self.widgetsData = widgetsData
 
+
 class IWidget(IView):
     """Generically describes the behavior of a widget.
 
@@ -190,6 +199,7 @@ class IWidget(IView):
 
         """
 
+
 class IInputWidget(IWidget):
     """A widget for editing a field value."""
 
@@ -249,6 +259,7 @@ class IInputWidget(IWidget):
         based on the field constraints.
         """
 
+
 class IDisplayWidget(IWidget):
     """A widget for displaying a field value."""
 
@@ -259,16 +270,19 @@ class IDisplayWidget(IWidget):
         Display widgets should never be required.
         """)
 
+
 class IWidgetFactory(Interface):
     """A factory that creates the widget"""
 
     def __call__(context, request):
         """Return a widget"""
 
+
 class FormError(Exception):
     """There was an error in managing the form
     """
 
+
 class IBrowserWidget(IWidget):
     """A widget for use in a web browser UI."""
 
@@ -310,19 +324,22 @@ class ITextBrowserWidget(ISimpleInputWidget):
 
     convert_missing_value = schema.Bool(
         title=u'Translate Input Value',
-        description=
-            u'If True, an empty string is converted to field.missing_value.',
+        description=(
+            u'If True, an empty string is converted to field.missing_value.'),
         default=True)
 
-# XXX this seems to be buggy (since at least 2005)
-# it returns None, and prefix_re is never defined.
-def reConstraint(pat, explanation):
+
+def reConstraint(pat, explanation, can_be_empty=False):
     pat = re.compile(pat)
 
     def constraint(value):
-        if prefix_re.match(value):
+        if not value and can_be_empty:
+            return True
+        if pat.match(value):
             return True
         raise Invalid(value, explanation)
+    return constraint
+
 
 class IWidgetInputErrorView(Interface):
     """Display an input error as a snippet of text."""
@@ -351,6 +368,7 @@ class ISourceQueryView(Interface):
         None may be returned to indicate that there are no results.
         """
 
+
 class ISubPage(Interface):
     """A component that computes part of a page
     """
@@ -374,7 +392,7 @@ class ISubPage(Interface):
         followed by a dot.
         """,
         readonly=True,
-        )
+    )
 
     def setPrefix(prefix):
         """Update the subpage prefix
@@ -418,7 +436,6 @@ class IFormAPI(Interface):
 
         """
 
-
     def Fields(*arguments, **options):
         """Create form-fields collection (`IFormFields`)
 
@@ -691,6 +708,7 @@ class IFormAPI(Interface):
     IFormBaseCustomization.
     """)
 
+
 class IFormBaseCustomization(ISubPage, IBrowserPage):
     """Attributes provided by the Form base class
 
@@ -775,7 +793,6 @@ class IFormBaseCustomization(ISubPage, IBrowserPage):
         """
 
 
-
 class IFormFields(Interface):
     """A colection of form fields (`IFormField` objects)
     """
@@ -826,9 +843,11 @@ class IFormFields(Interface):
         """Omit fields with given names
         """
 
+
 SKIP_UNAUTHORIZED = 2
 DISPLAY_UNWRITEABLE = 4
 
+
 class IFormField(Interface):
     """Definition of a field to be included in a form
 
@@ -838,29 +857,31 @@ class IFormField(Interface):
     __name__ = schema.ASCII(
         constraint=reConstraint('[a-zA-Z][a-zA-Z0-9_]*',
                                 "Must be an identifier"),
-        title = u"Field name",
+        title=u"Field name",
         description=u"""\
         This is the name, without any proefix, used for the field.
         It is usually the same as the name of the for field's schem field.
         """
-        )
+    )
 
     field = Attribute(
         """Schema field that defines the data of the form field
         """
-        )
+    )
 
     prefix = schema.ASCII(
-        constraint=reConstraint('[a-zA-Z][a-zA-Z0-9_]*',
-                                "Must be an identifier"),
+        constraint=reConstraint(
+            r'[a-zA-Z][a-zA-Z0-9_.]*', "Must be an identifier or empty",
+            can_be_empty=True),
         title=u"Prefix",
         description=u"""\
         Form-field prefix.  The form-field prefix is used to
         disambiguate fields with the same name (e.g. from different
         schema) within a collection of form fields.
         """,
+        required=False,
         default="",
-        )
+    )
 
     for_display = schema.Bool(
         title=u"Is the form field for display only?",
@@ -868,7 +889,7 @@ class IFormField(Interface):
         If this attribute has a true value, then a display widget will be
         used for the field even if it is writable.
         """
-        )
+    )
 
     for_input = schema.Bool(
         title=u"Is the form field for input?",
@@ -876,14 +897,14 @@ class IFormField(Interface):
         If this attribute has a true value, then an input widget will be
         used for the field even if it is readonly.
         """
-        )
+    )
 
     custom_widget = Attribute(
         """Factory to use for widget construction.
 
         If not set, normal view lookup will be used.
         """
-        )
+    )
 
     render_context = schema.Choice(
         title=u"Should the rendered value come from the form context?",
@@ -919,10 +940,10 @@ class IFormField(Interface):
             DISPLAY_UNWRITEABLE,
             SKIP_UNAUTHORIZED,
             DISPLAY_UNWRITEABLE | SKIP_UNAUTHORIZED,
-            )),
+        )),
         default=False,
         missing_value=False,
-        )
+    )
 
     get_rendered = Attribute(
         """Object to call to get a rendered value
@@ -938,7 +959,8 @@ class IFormField(Interface):
         - Data for the value is passed to setUpWidgets.
 
         """
-        )
+    )
+
 
 class IWidgets(Interface):
     """A widget collection
@@ -984,6 +1006,7 @@ class IWidgets(Interface):
 
         """
 
+
 class IForm(Interface):
     """Base type for forms
 
@@ -992,6 +1015,7 @@ class IForm(Interface):
 
     """
 
+
 class ISubPageForm(IForm, ISubPage):
     """A component that displays a part of a page.
 
@@ -1000,10 +1024,12 @@ class ISubPageForm(IForm, ISubPage):
 
     """
 
+
 class IPageForm(IForm, IBrowserPage):
     """A component that displays a form as a page.
     """
 
+
 class IAction(ISubPage):
     """Form submit actions
     """
@@ -1072,6 +1098,7 @@ class IAction(ISubPage):
         valid only after the action has been bound to a form.
         """
 
+
 class IActions(Interface):
     """An action collection
 
@@ -1103,6 +1130,7 @@ class IActions(Interface):
 
         """
 
+
 class IBoundAction(IAction):
     """An action that has been bound to a form
     """
