@@ -35,10 +35,10 @@ class ChoiceWidgetTest(PlacelessSetup, unittest.TestCase):
         field = Choice(values=[1, 2, 3])
         bound = field.bind(object())
         widget = ChoiceDisplayWidget(bound, TestRequest())
-        self.assert_(isinstance(widget, ItemDisplayWidget))
+        self.assertTrue(isinstance(widget, ItemDisplayWidget))
         self.assertEqual(widget.context, bound)
         self.assertEqual(widget.vocabulary, bound.vocabulary)
-    
+
     def test_ChoiceInputWidget(self):
         provideAdapter(DropdownWidget,
                        (IChoice, IIterableVocabulary, IBrowserRequest),
@@ -46,16 +46,12 @@ class ChoiceWidgetTest(PlacelessSetup, unittest.TestCase):
         field = Choice(values=[1, 2, 3])
         bound = field.bind(object())
         widget = ChoiceInputWidget(bound, TestRequest())
-        self.assert_(isinstance(widget, DropdownWidget))
+        self.assertTrue(isinstance(widget, DropdownWidget))
         self.assertEqual(widget.context, bound)
         self.assertEqual(widget.vocabulary, bound.vocabulary)
-        
 
 
 def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite(ChoiceWidgetTest),
-        ))
-
-if __name__=='__main__':
-    unittest.main(defaultTest='test_suite')
+    ))
