@@ -15,11 +15,10 @@
 """
 import unittest
 from doctest import DocTestSuite
+from .support import checker
+
 
 def test_suite():
     return unittest.TestSuite((
-        DocTestSuite('zope.formlib.exception'),
-        ))
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
+        DocTestSuite('zope.formlib.exception', checker=checker),
+    ))
