@@ -18,15 +18,17 @@ import unittest
 import re
 from datetime import datetime
 
-from zope.interface import Interface, implements
+from zope.interface import Interface, implementer
 from zope.schema import Datetime, Choice
 from zope.formlib import form
 from zope.publisher.browser import TestRequest
-from zope.formlib.widgets import DatetimeWidget, DropdownWidget, ChoiceInputWidget
+from zope.formlib.widgets import ChoiceInputWidget
+from zope.formlib.widgets import DatetimeWidget, DropdownWidget
 from zope.formlib.tests.functionalsupport import FunctionalWidgetTestCase
 import zope.schema.interfaces
 from zope.datetime import parseDatetimetz, tzinfo
 
+
 class IDatetimeTest(Interface):
     d1 = Datetime(
         required=True,
@@ -43,26 +45,28 @@ class IDatetimeTest(Interface):
             datetime(2003, 10, 15, tzinfo=tzinfo(0))),
         missing_value=datetime(2000, 1, 1, tzinfo=tzinfo(0)))
 
-class DatetimeTest(object):
 
-    implements(IDatetimeTest)
+@implementer(IDatetimeTest)
+class DatetimeTest(object):
 
     def __init__(self):
         self.d1 = datetime(2003, 4, 6, tzinfo=tzinfo(0))
         self.d2 = datetime(2003, 8, 6, tzinfo=tzinfo(0))
         self.d3 = None
 
+
 class Form(form.EditForm):
     form_fields = form.fields(IDatetimeTest)
-    
+
+
 class Test(FunctionalWidgetTestCase):
 
     widgets = [
         (zope.schema.interfaces.IDatetime, DatetimeWidget),
         (zope.schema.interfaces.IChoice, ChoiceInputWidget),
-        ((zope.schema.interfaces.IChoice, zope.schema.interfaces.IVocabularyTokenized),
-         DropdownWidget)]
-    
+        ((zope.schema.interfaces.IChoice,
+          zope.schema.interfaces.IVocabularyTokenized), DropdownWidget)]
+
     def getDateForField(self, field, source):
         """Returns a datetime object for the specified field in source.
 
@@ -86,14 +90,13 @@ class Test(FunctionalWidgetTestCase):
         request = TestRequest()
 
         html = Form(foo, request)()
-        
+
         # confirm date values in form with actual values
         self.assertEqual(self.getDateForField('d1', html),
-            foo.d1)
+                         foo.d1)
         self.assertEqual(self.getDateForField('d2', html),
-            foo.d2)
-        self.assert_(self.getDateForField('d3', html) is None)
-
+                         foo.d2)
+        self.assertTrue(self.getDateForField('d3', html) is None)
 
     def test_submit_editform(self):
         foo = DatetimeTest()
@@ -120,8 +123,8 @@ class Test(FunctionalWidgetTestCase):
 
         request.form['form.actions.apply'] = u''
         Form(foo, request)()
-        
-        self.assert_(foo.d2 is None) # default missing_value for dates
+
+        self.assertTrue(foo.d2 is None)  # default missing_value for dates
         # 2000-1-1 is missing_value for d3
         self.assertEqual(foo.d3, datetime(2000, 1, 1, tzinfo=tzinfo(0)))
 
@@ -135,16 +138,15 @@ class Test(FunctionalWidgetTestCase):
 
         request.form['form.actions.apply'] = u''
         html = Form(foo, request)()
-        
+
         # confirm error msgs
 
         # only Required input is missing after d1
         d1_index = html.find('form.d1')
-        self.assert_(html.find('Required input is missing', d1_index) != -1)
+        self.assertTrue(html.find('Required input is missing', d1_index) != -1)
         # but not after d2 or further
         d2_index = html.find('form.d2')
-        self.assert_(html.find('Required input is missing', d2_index) == -1)
-        
+        self.assertTrue(html.find('Required input is missing', d2_index) == -1)
 
     def test_invalid_value(self):
         foo = DatetimeTest()
@@ -157,7 +159,7 @@ class Test(FunctionalWidgetTestCase):
 
         # Invalid value message for d3
         d3_index = html.find('form.d3')
-        self.assert_(html.find('Invalid', d3_index) != -1)
+        self.assertTrue(html.find('Invalid', d3_index) != -1)
 
     def test_min_max_validation(self):
         foo = DatetimeTest()
@@ -167,11 +169,10 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.d1'] = u'2002-12-31 12:00:00+00:00'
         request.form['form.actions.apply'] = u''
         html = Form(foo, request)()
-        
-        d1_index = html.find('form.d1')
-        self.assert_(html.find('Value is too small') != -1)
+
+        self.assertTrue(html.find('Value is too small') != -1)
         d2_index = html.find('form.d2')
-        self.assert_(html.find('Value is too small', d2_index) == -1)
+        self.assertTrue(html.find('Value is too small', d2_index) == -1)
 
         request = TestRequest()
         # submit value for d1 that is too high
@@ -179,18 +180,18 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.actions.apply'] = u''
         html = Form(foo, request)()
 
-        self.assert_(html.find('Value is too big') != -1)
+        self.assertTrue(html.find('Value is too big') != -1)
         d2_index = html.find('form.d2')
-        self.assert_(html.find('Value is too big', d2_index) == -1)
+        self.assertTrue(html.find('Value is too big', d2_index) == -1)
 
     def test_omitted_value(self):
         foo = DatetimeTest()
         request = TestRequest()
-        
+
         # remember default values
         d1 = foo.d1
         d2 = foo.d2
-        self.assert_(d2 is not None)
+        self.assertTrue(d2 is not None)
         d3 = foo.d3
 
         # submit change with only d2 present -- note that required
@@ -199,12 +200,13 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.actions.apply'] = u''
 
         Form(foo, request)()
-        
+
         # check new value in object
         self.assertEqual(foo.d1, d1)
-        self.assert_(foo.d2 is None)
+        self.assertTrue(foo.d2 is None)
         self.assertEqual(foo.d3, d3)
 
+
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(Test))
