@@ -26,6 +26,7 @@ from zope.formlib.widgets import (
 from zope.formlib.tests.functionalsupport import FunctionalWidgetTestCase
 import zope.schema.interfaces
 
+
 class IFloatTest(Interface):
 
     f1 = Float(
@@ -41,6 +42,7 @@ class IFloatTest(Interface):
         values=(0.0, 1.1, 2.1, 3.1, 5.1, 7.1, 11.1),
         missing_value=0)
 
+
 @implementer(IFloatTest)
 class FloatTest(object):
 
@@ -49,16 +51,18 @@ class FloatTest(object):
         self.f2 = 1.1
         self.f3 = 2.1
 
+
 class Form(form.EditForm):
     form_fields = form.fields(IFloatTest)
-    
+
+
 class Test(FunctionalWidgetTestCase):
     widgets = [
         (zope.schema.interfaces.IFloat, FloatWidget),
         (zope.schema.interfaces.IChoice, ChoiceInputWidget),
-        ((zope.schema.interfaces.IChoice, zope.schema.interfaces.IVocabularyTokenized),
-         DropdownWidget)]
-    
+        ((zope.schema.interfaces.IChoice,
+          zope.schema.interfaces.IVocabularyTokenized), DropdownWidget)]
+
     def test_display_editform(self):
         foo = FloatTest()
         request = TestRequest()
@@ -67,15 +71,15 @@ class Test(FunctionalWidgetTestCase):
         html = Form(foo, request)()
 
         # f1 and f2 should be displayed in text fields
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<input .* name="form.f1".* value="".*>', html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<input .* name="form.f2".* value="1.1".*>', html))
 
         # f3 should be in a dropdown
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<select .*name="form.f3".*>', html))
-        self.assert_(patternExists(
+        self.assertTrue(patternExists(
             '<option selected="selected" value="2.1">2.1</option>',
             html))
 
@@ -89,7 +93,7 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.f3'] = '11.1'
         request.form['form.actions.apply'] = u''
         Form(foo, request)()
-        
+
         # check new values in object
         self.assertEqual(foo.f1, 1.123)
         self.assertEqual(foo.f2, 2.23456789012345)
@@ -105,16 +109,16 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.f3'] = '1.1'
         request.form['form.actions.apply'] = u''
         Form(foo, request)()
- 
+
         # check new values in object
         self.assertEqual(foo.f1, None)
-        self.assertEqual(foo.f2, None) # None is default missing_value
+        self.assertEqual(foo.f2, None)  # None is default missing_value
         self.assertEqual(foo.f3, 1.1)  # 0 is from f3.missing_value=0
 
     def test_required_validation(self):
         foo = FloatTest()
         request = TestRequest()
-        
+
         # submit missing values for required field f1
         request.form['form.f1'] = ''
         request.form['form.f2'] = ''
@@ -125,19 +129,19 @@ class Test(FunctionalWidgetTestCase):
         # confirm error msgs
         f3_index = html.find('form.f3')
         missing_index = html.find('missing')
-        self.assert_(missing_index > f3_index)
-        self.assert_(missing_index != -1)
+        self.assertTrue(missing_index > f3_index)
+        self.assertTrue(missing_index != -1)
 
     def test_invalid_allowed_value(self):
         foo = FloatTest()
         request = TestRequest()
-        
+
         # submit a value for f3 that isn't allowed
         request.form['form.f3'] = '10000'
         request.form['form.actions.apply'] = u''
         html = Form(foo, request)()
 
-        self.assert_('Invalid' in html)
+        self.assertTrue('Invalid' in html)
 
     def test_min_max_validation(self):
         foo = FloatTest()
@@ -148,7 +152,7 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.actions.apply'] = u''
         html = Form(foo, request)()
 
-        self.assert_('Value is too small' in html)
+        self.assertTrue('Value is too small' in html)
 
         request = TestRequest()
 
@@ -156,14 +160,14 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.actions.apply'] = u''
         html = Form(foo, request)()
 
-        self.assert_('Value is too big' in html)
+        self.assertTrue('Value is too big' in html)
 
     def test_omitted_value(self):
         foo = FloatTest()
         request = TestRequest()
 
         # confirm default values
-        self.assert_(foo.f1 is None)
+        self.assertTrue(foo.f1 is None)
         self.assertEqual(foo.f2, 1.1)
         self.assertEqual(foo.f3, 2.1)
 
@@ -174,8 +178,8 @@ class Test(FunctionalWidgetTestCase):
         Form(foo, request)()
 
         # check new value in object
-        self.assert_(foo.f1 is None)
-        self.assert_(foo.f2 is None)
+        self.assertTrue(foo.f1 is None)
+        self.assertTrue(foo.f2 is None)
         self.assertEqual(foo.f3, 2.1)
 
     def test_conversion(self):
@@ -187,10 +191,10 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.actions.apply'] = u''
         html = Form(foo, request)()
 
-        self.assert_('Invalid floating point data' in html)
+        self.assertTrue('Invalid floating point data' in html)
+
 
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(Test))
     return suite
-
