@@ -12,8 +12,6 @@
 #
 ##############################################################################
 """Textarea Widget tests
-
-$Id: test_textareawidget.py 112015 2010-05-05 18:27:23Z tseaver $
 """
 import unittest
 import doctest
@@ -22,6 +20,7 @@ from zope.formlib.widgets import TextAreaWidget
 from zope.formlib.tests.test_browserwidget import SimpleInputWidgetTest
 from zope.interface.verify import verifyClass
 
+
 class TextAreaWidgetTest(SimpleInputWidgetTest):
     """Documents and tests the text area widget.
 
@@ -57,7 +56,4 @@ def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite(TextAreaWidgetTest),
         doctest.DocTestSuite(),
-        ))
-
-if __name__=='__main__':
-    unittest.main(defaultTest='test_suite')
+    ))
