@@ -13,13 +13,14 @@
 ##############################################################################
 """Generic Widget Tests
 """
-from unittest import TestSuite, main
+from unittest import TestSuite
 
 from zope.component.testing import setUp, tearDown
 from zope.publisher.browser import TestRequest
 from doctest import DocTestSuite
 
 from zope.formlib.widget import Widget
+from .support import checker
 
 
 class TestContext(object):
@@ -27,12 +28,15 @@ class TestContext(object):
     title = 'My Test Context'
     description = 'A test context.'
 
+
 class FooWidget(Widget):
     pass
 
+
 context = TestContext()
 request = TestRequest()
 
+
 class TestWidget(object):
     """Tests basic widget characteristics.
 
@@ -92,6 +96,7 @@ class TestWidget(object):
     browser widget will render the specified value in HTML.
     """
 
+
 class TestInputWidget(object):
     """Tests the input widget mixin.
 
@@ -124,8 +129,9 @@ class TestInputWidget(object):
     field is read only:
 
         >>> field.readonly = True
-        >>> widget.getInputValue()
+        >>> widget.getInputValue() # doctest: +IGNORE_EXCEPTION_DETAIL
         Traceback (most recent call last):
+        ...
         WidgetInputError: ('', '', None)
 
     A call to hasValidInput returns False instead of raising an error:
@@ -146,6 +152,7 @@ class TestInputWidget(object):
         True
     """
 
+
 class TestCustomWidgetFactory(object):
     """Tests the custom widget factory.
 
@@ -175,7 +182,7 @@ class TestCustomWidgetFactory(object):
         >>> value_type = TextLine(__name__=u'bar')
         >>> field = List( __name__=u'foo', value_type=value_type )
 
-        >>> factory = CustomWidgetFactory(ListSequenceWidget, 
+        >>> factory = CustomWidgetFactory(ListSequenceWidget,
         ...     subwidget=CustomWidgetFactory(FooWidget, bar='baz'))
 
         >>> widget = factory(field, request)
@@ -199,7 +206,7 @@ class TestCustomWidgetFactory(object):
         >>> field = Choice( __name__=u'foo', values=['1', '2', '3'] )
         >>> bound = field.bind(context)
 
-        >>> factory = CustomWidgetFactory(RadioWidget, 
+        >>> factory = CustomWidgetFactory(RadioWidget,
         ...      orientation = 'vertical')
 
         >>> widget = factory(bound, request)
@@ -216,8 +223,5 @@ class TestCustomWidgetFactory(object):
 
 def test_suite():
     return TestSuite((
-        DocTestSuite(setUp=setUp, tearDown=tearDown),
-        ))
-
-if __name__=='__main__':
-    main(defaultTest='test_suite')
+        DocTestSuite(setUp=setUp, tearDown=tearDown, checker=checker),
+    ))
