@@ -37,11 +37,12 @@ from zope.formlib.interfaces import IWidgetFactory
 # accept a 'value' argument.
 no_value = object()
 
+
 def _fieldlist(names, schema):
     if not names:
         fields = getFieldsInOrder(schema)
     else:
-        fields = [ (name, schema[name]) for name in names ]
+        fields = [(name, schema[name]) for name in names]
     return fields
 
 
@@ -50,6 +51,7 @@ def _createWidget(context, field, viewType, request):
     field = field.bind(context)
     return component.getMultiAdapter((field, request), viewType)
 
+
 def _widgetHasStickyValue(widget):
     """Returns ``True`` if the widget has a sticky value.
 
@@ -61,6 +63,7 @@ def _widgetHasStickyValue(widget):
     """
     return IInputWidget.providedBy(widget) and widget.hasInput()
 
+
 def setUpWidget(view, name, field, viewType, value=no_value, prefix=None,
                 ignoreStickyValues=False, context=None):
     """Sets up a single view widget.
@@ -97,7 +100,7 @@ def setUpWidget(view, name, field, viewType, value=no_value, prefix=None,
         widget.setPrefix(prefix)
 
     if value is not no_value and (
-        ignoreStickyValues or not _widgetHasStickyValue(widget)):
+            ignoreStickyValues or not _widgetHasStickyValue(widget)):
         widget.setRenderedValue(value)
 
 
@@ -162,7 +165,7 @@ def applyWidgetsChanges(view, schema, target=None, names=None):
         if IInputWidget.providedBy(widget) and widget.hasInput():
             try:
                 changed = widget.applyChanges(target) or changed
-            except InputErrors, v:
+            except InputErrors as v:
                 errors.append(v)
     if errors:
         raise WidgetsError(errors)
